@@ -18,7 +18,7 @@ BUILD_DATE=""
 def get_outlets_status(conn, options):
 	try:
 		conn.sendline("virsh list --all")
-		conn.log_expect(options, options["-c"], SHELL_TIMEOUT)
+		conn.log_expect(options, options["-c"], int(options["-Y"]))
 	except pexpect.EOF:
 		fail(EC_CONNECTION_LOST)
 	except pexpect.TIMEOUT:
@@ -51,7 +51,7 @@ def set_power_status(conn, options):
 	try:
 		conn.sendline("virsh %s "%(options["-o"] == "on" and "start" or "destroy")+options["-n"])
 
-		conn.log_expect(options, options["-c"], POWER_TIMEOUT)
+		conn.log_expect(options, options["-c"], int(options["-g"]))
                 time.sleep(1)
 
 	except pexpect.EOF:
@@ -63,25 +63,35 @@ def main():
 	device_opt = [  "help", "version", "agent", "quiet", "verbose", "debug",
 			"action", "ipaddr", "login", "passwd", "passwd_script",
 			"secure", "identity_file", "test", "port", "separator",
-			"inet4_only", "inet6_only", "ipport" ]
+			"inet4_only", "inet6_only", "ipport",
+			"power_timeout", "shell_timeout", "login_timeout", "power_wait" ]
 
 	atexit.register(atexit_handler)
 
-	options = check_input(device_opt, process_input(device_opt))
+	pinput = process_input(device_opt)
+	pinput["-x"] = 1
+	options = check_input(device_opt, pinput)
 
 	## Defaults for fence agent
 	if 0 == options.has_key("-c"):
 		options["-c"] = "\[EXPECT\]#\ "
 
-	options["-x"]=1
-
 	options["ssh_options"]="-t '/bin/bash -c \"PS1=\[EXPECT\]#\  /bin/bash --noprofile --norc\"'"
 
-	show_docs(options)
+	docs = { }
+	docs["shortdesc"] = "Fence agent for virsh"
+	docs["longdesc"] = "fence_virsh is an I/O Fencing agent \
+which can be used with the virtual machines managed by libvirt. \
+It logs via ssh to a dom0 and there run virsh command, which does \
+all work. \
+\n.P\n\
+By default, virsh needs root account to do properly work. So you \
+must allow ssh login in your sshd_config."
+	show_docs(options, docs)
 
 	## Operate the fencing device
 	conn = fence_login(options)
-	fence_action(conn, options, set_power_status, get_power_status, get_outlets_status)
+	result = fence_action(conn, options, set_power_status, get_power_status, get_outlets_status)
 
 	## Logout from system
 	try:
@@ -92,5 +102,6 @@ def main():
 	except pexpect.ExceptionPexpect:
 		pass
 
+	sys.exit(result)
 if __name__ == "__main__":
 	main()
